#include <shogun/base/init.h>
#include <shogun/base/some.h>
#include <shogun/labels/MulticlassLabels.h>
#include <shogun/metric/LMNN.h>
#include <shogun/io/SerializableAsciiFile.h>
#include <shogun/lib/WrappedObjectArray.h>
#include <shogun/features/DenseFeatures.h>
#include <shogun/io/CSVFile.h>
#include <shogun/lib/SGVector.h>
#include <shogun/evaluation/MulticlassAccuracy.h>
#include <shogun/distance/CustomMahalanobisDistance.h>
#include <shogun/multiclass/KNN.h>

using namespace shogun;

int main(int, char*[])
{
init_shogun_with_defaults();

auto f_feats_train = some<CCSVFile>("../../data/classifier_4class_2d_linear_features_train.dat");
auto f_feats_test = some<CCSVFile>("../../data/classifier_4class_2d_linear_features_test.dat");
auto f_labels_train = some<CCSVFile>("../../data/classifier_4class_2d_linear_labels_train.dat");
auto f_labels_test = some<CCSVFile>("../../data/classifier_4class_2d_linear_labels_test.dat");

//![create_features]
auto features_train = some<CDenseFeatures<float64_t>>(f_feats_train);
auto features_test = some<CDenseFeatures<float64_t>>(f_feats_test);
auto labels_train = some<CMulticlassLabels>(f_labels_train);
auto labels_test = some<CMulticlassLabels>(f_labels_test);
//![create_features]

//![create_instance]
auto k = 3;
auto lmnn = some<CLMNN>(features_train, labels_train, k);
//![create_instance]

//![train_metric]
lmnn->train();
auto lmnn_distance = lmnn->get_distance();
//![train_metric]

//![train_and_apply]
auto knn = some<CKNN>(k, lmnn_distance, labels_train);
knn->train();
auto labels_predict = knn->apply_multiclass(features_test);
//![train_and_apply]

//![evaluate_accuracy]	
auto acc = some<CMulticlassAccuracy>();
auto accuracy = acc->evaluate(labels_predict, labels_test);
//![evaluate_accuracy]

// additional integration testing variables
auto output = labels_predict->get_labels();


// Serialize output for integration testing (automatically generated)
auto __sg_storage = some<CWrappedObjectArray>();
auto __sg_storage_file = some<CSerializableAsciiFile>("large_margin_nearest_neighbours.dat", 'w');
__sg_storage->append_wrapped_int(k, "k");
__sg_storage->append_wrapped_real(accuracy, "accuracy");
__sg_storage->append_wrapped_real_vector(output, "output");
__sg_storage->save_serializable(__sg_storage_file);

exit_shogun();
return 0;
}
