import numpy as np
from modshogun import RealFeatures
from modshogun import WrappedObjectArray
from modshogun import NormOne
from modshogun import CSVFile
from modshogun import SerializableAsciiFile
from modshogun import LeastAngleRegression
from modshogun import RegressionLabels
from modshogun import PruneVarSubMean
from modshogun import MeanSquaredError

f_feats_train = CSVFile("../../data/regression_1d_linear_features_train.dat")
f_feats_test = CSVFile("../../data/regression_1d_linear_features_test.dat")
f_labels_train = CSVFile("../../data/regression_1d_linear_labels_train.dat")
f_labels_test = CSVFile("../../data/regression_1d_linear_labels_test.dat")

#![create_features]
features_train = RealFeatures(f_feats_train)
features_test = RealFeatures(f_feats_test)
labels_train = RegressionLabels(f_labels_train)
labels_test = RegressionLabels(f_labels_test)
#![create_features]

#![preprocess_features]
SubMean = PruneVarSubMean()
Normalize = NormOne()
SubMean.init(features_train)
SubMean.apply_to_feature_matrix(features_train)
SubMean.apply_to_feature_matrix(features_test)
Normalize.init(features_train)
Normalize.apply_to_feature_matrix(features_train)
Normalize.apply_to_feature_matrix(features_test)
#![preprocess_features]

#![create_instance]
lamda1 = 0.01
lars = LeastAngleRegression(False)
lars.set_features(features_train)
lars.set_labels(labels_train)
lars.set_max_l1_norm(lamda1)
#![create_instance]

#![train_and_apply]
lars.train()
labels_predict = lars.apply_regression(features_test)

#[!extract_w]
weights = lars.get_w()
#[!extract_w]

#![evaluate_error]
eval = MeanSquaredError()
mse = eval.evaluate(labels_predict, labels_test)
#![evaluate_error]

# integration testing variables
output = labels_test.get_labels()


# Serialize output for integration testing (automatically generated)
__sg_storage = WrappedObjectArray()
__sg_storage_file = SerializableAsciiFile("least_angle_regression.dat", 'w')
__sg_storage.append_wrapped_real(lamda1, "lamda1")
__sg_storage.append_wrapped_real_vector(weights, "weights")
__sg_storage.append_wrapped_real(mse, "mse")
__sg_storage.append_wrapped_real_vector(output, "output")
__sg_storage.save_serializable(__sg_storage_file)
