require 'modshogun'

f_feats_train = Modshogun::CSVFile.new "../../data/classifier_4class_2d_linear_features_train.dat"
f_feats_test = Modshogun::CSVFile.new "../../data/classifier_4class_2d_linear_features_test.dat"
f_labels_train = Modshogun::CSVFile.new "../../data/classifier_4class_2d_linear_labels_train.dat"
f_labels_test = Modshogun::CSVFile.new "../../data/classifier_4class_2d_linear_labels_test.dat"
Modshogun::Math.init_random 1

#![create_features]
features_train = Modshogun::RealFeatures.new f_feats_train
features_test = Modshogun::RealFeatures.new f_feats_test
labels_train = Modshogun::MulticlassLabels.new f_labels_train
labels_test = Modshogun::MulticlassLabels.new f_labels_test
#![create_features]

#![create_appropriate_kernel_and_mean_function]
kernel = Modshogun::GaussianKernel.new 2.0
mean_function = Modshogun::ConstMean.new 
#![create_appropriate_kernel_and_mean_function]

#![create_instance]
gauss_likelihood = Modshogun::SoftMaxLikelihood.new 
inference_method = Modshogun::MultiLaplaceInferenceMethod.new kernel, features_train, mean_function, labels_train, gauss_likelihood
gp_classifier = Modshogun::GaussianProcessClassification.new inference_method
#![create_instance]

#![train_and_apply]
gp_classifier.train 
labels_predict = gp_classifier.apply_multiclass features_test
#![train_and_apply]

#![extract_the_probabilities]
prob = gp_classifier.get_probabilities features_train
#![extract_the_probabilities]

#![evaluate_accuracy]
evals = Modshogun::MulticlassAccuracy.new 
accuracy = evals.evaluate labels_predict, labels_test
#![evaluate_accuracy]

# integration testing variables
output = labels_test.get_labels 

# Serialize output for integration testing (automatically generated)
__sg_storage = Modshogun::WrappedObjectArray.new 
__sg_storage_file = Modshogun::SerializableAsciiFile.new "gaussian_process_classifier.dat", 'w'
__sg_storage.append_wrapped_real_vector prob, "prob"
__sg_storage.append_wrapped_real accuracy, "accuracy"
__sg_storage.append_wrapped_real_vector output, "output"
__sg_storage.save_serializable __sg_storage_file
