require 'modshogun'

f_features_p = Modshogun::CSVFile.new "../../data/two_sample_test_gaussian.dat"
f_features_q = Modshogun::CSVFile.new "../../data/two_sample_test_laplace.dat"

#![create_features]
features_p = Modshogun::RealFeatures.new f_features_p
features_q = Modshogun::RealFeatures.new f_features_q
#![create_features]

#![create_instance]
mmd = Modshogun::QuadraticTimeMMD.new features_p, features_q
kernel = Modshogun::GaussianKernel.new 10, 1
mmd.set_kernel kernel
alpha = 0.05
#![create_instance]

#![estimate_mmd]
mmd.set_statistic_type Modshogun::ST_BIASED_FULL
statistic = mmd.compute_statistic 
#![estimate_mmd]

#![perform_test]
mmd.set_null_approximation_method Modshogun::NAM_PERMUTATION
mmd.set_num_null_samples 200
threshold = mmd.compute_threshold alpha
p_value = mmd.compute_p_value statistic
#![perform_test]

#![add_kernels]
kernel1 = Modshogun::GaussianKernel.new 10, 0.1
kernel2 = Modshogun::GaussianKernel.new 10, 1
kernel3 = Modshogun::GaussianKernel.new 10, 10
mmd.add_kernel kernel1
mmd.add_kernel kernel2
mmd.add_kernel kernel3
#![add_kernels]

#![multi_kernel]
mk = mmd.multikernel 
mk.add_kernel kernel1
mk.add_kernel kernel2
mk.add_kernel kernel2

mk_statistic = mk.compute_statistic 
mk_p_value = mk.compute_p_value 
#![multi_kernel]

#![enable_train_test_mode]
mmd.set_train_test_mode true
mmd.set_train_test_ratio 1
#![enable_train_test_mode]

#![select_kernel_single]
num_runs = 1
num_folds = 3
mmd.set_kernel_selection_strategy Modshogun::KSM_CROSS_VALIDATION, num_runs, num_folds, alpha
mmd.select_kernel 
learnt_kernel_single = Modshogun::GaussianKernel.obtain_from_generic mmd.get_kernel 
width = learnt_kernel_single.get_width 
#![select_kernel_single]

#![select_kernel_combined]
mmd.set_kernel_selection_strategy Modshogun::KSM_MAXIMIZE_MMD, true
mmd.select_kernel 
learnt_kernel_combined = Modshogun::CombinedKernel.obtain_from_generic mmd.get_kernel 
weights = learnt_kernel_combined.get_subkernel_weights 
#![select_kernel_combined]

#![perform_test_optimized]
statistic_optimized = mmd.compute_statistic 
p_value_optimized = mmd.compute_p_value statistic
#![perform_test_optimized]

# Serialize output for integration testing (automatically generated)
__sg_storage = Modshogun::WrappedObjectArray.new 
__sg_storage_file = Modshogun::SerializableAsciiFile.new "quadratic_time_mmd.dat", 'w'
__sg_storage.append_wrapped_real alpha, "alpha"
__sg_storage.append_wrapped_real statistic, "statistic"
__sg_storage.append_wrapped_real threshold, "threshold"
__sg_storage.append_wrapped_real p_value, "p_value"
__sg_storage.append_wrapped_real_vector mk_statistic, "mk_statistic"
__sg_storage.append_wrapped_real_vector mk_p_value, "mk_p_value"
__sg_storage.append_wrapped_int num_runs, "num_runs"
__sg_storage.append_wrapped_int num_folds, "num_folds"
__sg_storage.append_wrapped_real width, "width"
__sg_storage.append_wrapped_real_vector weights, "weights"
__sg_storage.append_wrapped_real statistic_optimized, "statistic_optimized"
__sg_storage.append_wrapped_real p_value_optimized, "p_value_optimized"
__sg_storage.save_serializable __sg_storage_file
